#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2012. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************

# ################################################################################
#
# File for messages displayed by the upgrade automated scripts.
#
# ################################################################################


# *********************
# * Messages function *
# *********************
messages() {

case $1 in

# *********************************
# * Initial verification messages *
# *********************************

INVALID_LAUNCH )
echo ""
echo "Führen Sie das Script 'app_upgrade' nicht direkt aus. Führen Sie für ein Anwendungsupgrade folgenden Befehl aus:"
echo "    relm_upgrade"
echo "Mit '-help' können Sie eine vollständige Beschreibung des obigen Befehls anzeigen."
;;

INVALID_START_DIR )
echo ""
echo "Das Script '$2' muss im Verzeichnis '$3' ausgeführt werden, außer Sie verwenden den Parameter '-help'."
echo ""
;;


SHOW_PARAM_FILE_NAME )
echo ""
echo "Die Datei '$2' enthält die Parameterwerte für das Upgrade-Script."
echo "Falls Sie Standardparameterwerte ändern müssen, können Sie diese Dateien bearbeiten oder die Parameterwerte als Befehlszeilenargumente für die Upgrade-Scripts angeben."
echo ""
;;

SHOW_PARAM_FILE_NAMES_LIST )
echo ""
echo "Die Standardparameterwerte für ein Anwendungsupgrade sind in folgender Datei enthalten. Falls Sie Standardparameterwerte ändern müssen, können Sie diese Datei bearbeiten oder die Parameterwerte als Befehlszeilenargumente für das Upgrade-Script angeben."
echo "- RELM-Upgrade:  $2/params/relm_params$3.sh"
echo ""
;;


# ************************************
# * Parameters verification messages *
# ************************************

# Intrinsic verification
# ======================

MISSING_APP_TYPE )
echo ""
echo "Es wurde kein Anwendungstyp angegeben. Führen Sie für ein Anwendungsupgrade folgenden Befehl aus:"
echo "    relm_upgrade"
echo "Mit '-help' können Sie eine vollständige Beschreibung des obigen Befehls anzeigen."
echo ""
;;

INVALID_APP_TYPE )
echo ""
echo "'$2' ist kein gültiger Anwendungstyp. Führen Sie für ein Anwendungsupgrade folgenden Befehl aus:"
echo "    relm_upgrade"
echo "Mit '-help' können Sie eine vollständige Beschreibung des obigen Befehls anzeigen."
echo ""
;;

MISSING_PARAM_VALUE )
echo ""
echo "Fehlender Wert für Parameter '$2'."
echo "Mit '-help' können Sie eine vollständige Parameterbeschreibung anzeigen."
echo ""
;;

INVALID_PARAM_DIR )
echo ""
echo "Das für den Parameter '$2' angegebene Verzeichnis '$3' ist nicht vorhanden oder ungültig."
echo "Mit '-help' können Sie eine vollständige Parameterbeschreibung anzeigen."
echo ""
;;

RELATIVE_PARAM_DIR )
echo ""
echo "Das für den Parameter '$2' angegebene Verzeichnis '$3' muss ein absoluter Pfad sein."
echo "Mit '-help' können Sie eine vollständige Parameterbeschreibung anzeigen."
echo ""
;;

INVALID_PARAM_FILE )
echo ""
echo "Die für den Parameter '$2' angegebene Datei '$3' ist nicht vorhanden oder ungültig."
echo "Mit '-help' können Sie eine vollständige Parameterbeschreibung anzeigen."
echo ""
;;

INVALID_PARAM_VALUE )
echo ""
echo "'$3' ist ein ungültiger Wert für den Parameter '$2'."
echo "Mit '-help' können Sie eine vollständige Parameterbeschreibung anzeigen."
echo ""
;;

INVALID_PARAM )
echo ""
echo "'$2' ist ein unbekannter Parameter."
echo "Mit '-help' können Sie eine vollständige Parameterbeschreibung anzeigen."
echo ""
;;


# Extrinsic verification
# ======================

MISSING_HOME_PARAM )
echo ""
echo "Fehlender Parameter '$2' für das Ausgangsverzeichnis."
echo "Mit '-help' können Sie eine vollständige Parameterbeschreibung anzeigen."
echo ""
;;

DIR_NOT_FOUND )
echo ""
echo "Das Verzeichnis '$2' ist nicht vorhanden oder ungültig."
echo ""
;;

CMD_NOT_FOUND_2X_APP )
echo ""
echo "Der repotools-Befehl '$2' für die Anwendung wurde nicht gefunden."
echo ""
echo "Stellen Sie sicher, dass der Parameter '-oldApplicationHome' ('$3') auf das alte Serverkonfigurationsverzeichnis verweist, z. B. auf 'JazzInstallDir/server/conf'."
echo ""
;;

CMD_NOT_FOUND_OLD_APP )
echo ""
echo "Der repotools-Befehl '$2' für die Anwendung wurde nicht gefunden."
echo ""
echo "Stellen Sie sicher, dass der Parameter '-oldApplicationHome' ('$3') auf das alte Serverkonfigurationsverzeichnis verweist, z. B. auf 'JazzInstallDir/server/conf', und dass der Parameter 'jtsContextRoot' ('$4') korrekt ist."
echo ""
;;

TSP_NOT_FOUND_2X_APP )
echo ""
echo "Die Konfigurationsdatei '$2' wurde nicht gefunden."
echo ""
echo "Stellen Sie sicher, dass der Parameter '-oldApplicationHome' ('$3') auf das alte Serverkonfigurationsverzeichnis verweist, z. B. auf 'JazzInstallDir/server/conf'."
echo ""
;;

TSP_NOT_FOUND_OLD_APP )
echo ""
echo "Die Konfigurationsdatei '$2' wurde nicht gefunden."
echo ""
echo "Stellen Sie sicher, dass der Parameter '-oldApplicationHome' ('$3') auf das alte Serverkonfigurationsverzeichnis verweist, z. B. auf 'JazzInstallDir/server/conf', und dass der Parameter 'jtsContextRoot' ('$4') korrekt ist."
echo ""
;;

CMD_NOT_FOUND_NEW_APP )
echo ""
echo "Der repotools-Befehl '$2' für die Anwendung wurde nicht gefunden."
echo ""
echo "Stellen Sie sicher, dass der Parameter '-newApplicationHome' ('$3') auf das neue Anwendungsserverkonfigurationsverzeichnis verweist, z. B. auf 'JazzInstallDir/server/conf', und dass der Parameter 'jtsContextRoot' ('$4') korrekt ist."
echo "Falls Sie ein Upgrade für ein früheres Release durchführen, vergewissern Sie sich, dass Sie die korrekten Kontextstammverzeichnisse ausgewählt haben. Bei Verwendung des Installation Manager müssen Sie beispielsweise die Option '$5' für das Kontextstammverzeichnis in der "Context Root Options"Anzeige auswählen. Sollten Sie versehentlich eine andere Option ausgewählt haben, müssen Sie das Produkt mit der Option '$5' für das Kontextstammverzeichnis erneut installieren."
echo ""
;;

TSP_NOT_FOUND_NEW_APP )
echo ""
echo "Die Konfigurationsdatei '$2' wurde nicht gefunden."
echo ""
echo "Stellen Sie sicher, dass der Parameter '-newApplicationHome' ('$3') auf das neue JTS-Serverkonfigurationsverzeichnis verweist, z. B. auf 'JazzInstallDir/server/conf', und dass der Parameter 'jtsContextRoot' ('$4') korrekt ist."
echo "Falls Sie ein Upgrade für ein früheres Release durchführen, vergewissern Sie sich, dass Sie die korrekten Kontextstammverzeichnisse ausgewählt haben. Bei Verwendung des Installation Manager müssen Sie beispielsweise die Option '$5' für das Kontextstammverzeichnis in der "Context Root Options"Anzeige auswählen. Sollten Sie versehentlich eine andere Option ausgewählt haben, müssen Sie das Produkt mit der Option '$5' für das Kontextstammverzeichnis erneut installieren."
echo ""
;;

CMD_NOT_FOUND_OLD_JTS )
echo ""
echo "Der repotools-Befehl '$2' für den JTS wurde nicht gefunden."
echo ""
echo "Stellen Sie sicher, dass der Parameter '-oldJTSHome' ('$3') auf das alte JTS-Serverkonfigurationsverzeichnis verweist, z. B. auf 'JazzInstallDir/server/conf', und dass der Parameter 'jtsContextRoot' ('$4') korrekt ist."
echo ""
;;

TSP_NOT_FOUND_OLD_JTS )
echo ""
echo "Die Konfigurationsdatei '$2' wurde nicht gefunden."
echo ""
echo "Stellen Sie sicher, dass der Parameter '-oldJTSHome' ('$3') auf das alte JTS-Serverkonfigurationsverzeichnis verweist, z. B. auf 'JazzInstallDir/server/conf', und dass der Parameter 'jtsContextRoot' ('$4') korrekt ist."
echo ""
;;

CMD_NOT_FOUND_NEW_JTS )
echo ""
echo "Der repotools-Befehl '$2' für den JTS wurde nicht gefunden."
echo ""
echo "Stellen Sie sicher, dass der Parameter '-newJTSHome' ('$3') auf das neue JTS-Serverkonfigurationsverzeichnis verweist, z. B. auf 'JazzInstallDir/server/conf', und dass der Parameter 'jtsContextRoot' ('$4') korrekt ist."
echo ""
;;

TSP_NOT_FOUND_NEW_JTS )
echo ""
echo "Die Konfigurationsdatei '$2' wurde nicht gefunden."
echo ""
echo "Stellen Sie sicher, dass der Parameter '-newJTSHome' ('$3') auf das neue JTS-Serverkonfigurationsverzeichnis verweist, z. B. auf 'JazzInstallDir/server/conf', und dass der Parameter 'jtsContextRoot' ('$4') korrekt ist."
echo ""
;;

MISSING_IMPORT_FROM_FILE )
echo ""
echo "Für ein Upgrade von '$2' ist eine TAR-Datei mit 2.x-Daten erforderlich."
echo "Mit '-help' können Sie eine vollständige Parameterbeschreibung anzeigen."
echo ""
;;


# **********************
# * Execution messages *
# **********************

BANNER_relm )
echo ""
echo ""
echo "============================================"
echo "===    RELM-Upgrade    ==="
echo "============================================"
echo ""
;;


# *********************
# * First step switch *
# *********************

INITIAL_STEP_FAILED )
echo ""
echo "Letzte Ausführung schlug im Anfangsschritt fehl ..."
;;

LAST_STEP_FAILED )
echo ""
echo "Letzte Ausführung schlug im Schritt '$2' fehl ..."
echo "Soll das Upgrade bei diesem oder einem früheren Schritt neu gestartet werden?"
;;

ALREADY_RUN )
echo ""
echo "Das Upgrade wurde bereits durchgeführt und erfolgreich beendet ..."
echo "Soll ein neues Upgrade bei einem bestimmten Schritt gestartet werden?"
;;

LAST_STEP_PASSED )
echo ""
echo "Letzte Ausführung wurde in Schritt '$2' erfolgreich gestoppt ..."
echo "Soll das Upgrade bei dem aktuellen Schritt '$3' oder einem früheren Schritt neu gestartet werden?"
;;

ENTER_NEXT_STEP )
echo ""
echo "Geben Sie die Nummer des Schritts ['$2'-'$3'] ein, bei dem das Upgrade erneut gestartet werden soll, oder brechen Sie mit [Eingabetaste] ab:"
;;

INTEGER_STEP_NUMBER )
echo ""
echo "'$2' ist keine Zahl. Geben Sie eine gültige Schrittnummer ein."
;;

INVALID_STEP_NUMBER )
echo ""
echo "'$2' ist eine ungültige Schrittnummer. Geben Sie eine gültige Schrittnummer ein."
;;

MAX_STEP_NUMBER )
echo ""
echo "Der letzte Schritt ist Schritt '$2', sodass das Upgrade nicht bei Schritt '$3' erneut gestartet werden kann."
;;

NUM_MAX_STEP_NUMBER )
echo ""
echo "Schritt '$2' wurde noch nicht ausgeführt, sodass das Upgrade nicht bei Schritt '$3' erneut gestartet werden kann."
;;


# **********************
# * Messages for Steps *
# **********************

STEP_0_IBMi )
echo "Schritt 0: Tabellen freigeben"
echo "-------------------"
;;

STEP_0 )
echo "Schritt 0: Konfigurationsdateien aktualisieren"
echo "---------------------------"
;;

STEP_1_ADD )
echo "Schritt 1: Tabellen hinzufügen"
echo "------------------"
;;

FULL_TEXT_INDICES_STEP )
echo "Schritt '$2': Textindizes erneut erstellen"
echo "----------------------------"
;;

JFS_INDICES_STEP )
echo "Schritt '$2': Abfrage und Suchindizes erneut erstellen"
echo "-----------------------------------------"
;;

STEP_2_UPGRADE_DATA_WAREHOUSE )
echo "Schritt 2: Upgrade für Data-Warehouse-Schema durchführen"
echo "-------------------------------------"
;;

OVERALL_MIGRATION_FAILED )
echo ""
echo "Das Upgrade für '$2' schlug bei Schritt '$3' fehl. Lösen Sie das Problem. Führen Sie das Script anschließend erneut ab Schritt '$3' aus."
echo ""
;;

OVERALL_MIGRATION_SUCCESS_RELM )
echo ""
echo "Das Upgrade für '$2' war erfolgreich. Falls Sie ebenfalls ein JTS-Upgrade und ein Upgrade für alle zugehörigen Anwendungen (wie VVC, LQE und Sparql_Gateway) durchgeführt haben, können Sie nun die Server in der Implementierung starten."
echo ""
;;

# *******************************
# * Messages while running step *
# *******************************

STEP_DIR_CMD )
echo ""
echo "Verzeichnis: '$2'"
echo "Befehl:"
;;

ENTER_STEP_ACTION )
echo "Geben Sie [E] für die Ausführung dieses Schritts oder [S] zum Überspringen ein oder brechen Sie die Scriptausführung mit [Eingabetaste] ab:"
;;

INVALID_STEP_ACTION )
echo ""
echo "'$2' ist eine ungültige Eingabe. Zulässig ist nur 'E', 'S' oder 'Eingabetaste'."
echo ""
;;

EDIT_TEAMSERVER_PROPERTIES )
echo ""
echo "Ein vi-Editor wird geöffnet, in dem Sie die Datei 'teamserver.properties' von '$2' überprüfen können."
echo "Prüfen Sie, ob das von der Eigenschaft 'com.ibm.team.repository.server.webapp.url' angegebene Stammelement des öffentlichen URI korrekt ist."
echo "Prüfen Sie, ob die Datenbankeigenschaften korrekt sind."
echo "Speichern Sie gegebenenfalls vorgenommene Änderungen. Schließen Sie anschließend den Editor und fahren Sie mit der Scriptausführung fort."
echo ""
;;

PAUSE )
echo ""
echo "Geben Sie zum Fortsetzen der Ausführung [C] ein oder drücken Sie zum Abbrechen der Scriptausführung die [Eingabetaste]."
;;

INVALID_PAUSE_ACTION )
echo ""
echo "'$2' ist eine ungültige Eingabe. Zulässig ist nur 'C' oder 'Eingabetaste'. "
echo ""
;;

COPY_INDICES_FAILED )
echo ""
echo "Die Textindizes konnten nicht von '$2' in '$3' kopiert werden."
echo "Prüfen Sie die Eigenschaft 'com.ibm.team.fulltext.indexLocation',"
echo "die in der Datei 'teamserver.properties' definiert ist."
echo "Kopieren Sie die Textindizes manuell in dieses Verzeichnis"
echo "oder führen Sie zur Neuerstellung der Indizes 'repotools -rebuildTextIndices' aus."
echo ""
;;

# *****************************************
# * Messages for Public URIs verification *
# *****************************************

MISSING_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! FEHLER !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "Ein öffentlicher URI ist nicht in"
echo "'$3'"
echo "definiert. Das Upgrade kann daher nicht gestartet werden."
echo ""
echo "Diese Datei muss einen wie folgt definierten öffentlichen URI enthalten:"
echo "https\://hostname.example.com\:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "Die Eigenschaft 'com.ibm.team.repository.server.webapp.url' für den öffentlichen URI muss in der Datei 'teamserver.properties' enthalten sein."
echo "Fügen Sie die Eigenschaft zur Datei 'teamserver.properties' der alten Installation hinzu und legen Sie für alle Clients fest, dass der Wert der Eigenschaft als URI-Stammelement für den Kontakt zum Server verwendet werden soll."
echo "Das Stammelement des öffentlichen URI ist wesentliche Voraussetzung für die ordnungsgemäße Funktionsfähigkeit der neuen Installation. Ohne diese Eigenschaft ist kein erfolgreiches Upgrade möglich."
echo "Weitere Informationen hierzu enthält das Thema 'URIs planen' im Information Center."
echo ""
;;

COMMENTED_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! FEHLER !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "Alle öffentlichen URIs, die in"
echo "'$3'"
echo "definiert sind, sind auf Kommentar gesetzt, sodass das Upgrade nicht gestartet werden kann."
echo ""
echo "Diese Datei muss einen wie folgt definierten öffentlichen URI enthalten, der nicht auf Kommentar gesetzt ist:"
echo "https/://hostname.example.com/:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "Die Eigenschaft 'com.ibm.team.repository.server.webapp.url' für den öffentlichen URI muss in der Datei 'teamserver.properties' enthalten sein."
echo "Fügen Sie die Eigenschaft zur Datei 'teamserver.properties' der alten Installation hinzu und legen Sie für alle Clients fest, dass der Wert der Eigenschaft als URI-Stammelement für den Kontakt zum Server verwendet werden soll."
echo "Das Stammelement des öffentlichen URI ist wesentliche Voraussetzung für die ordnungsgemäße Funktionsfähigkeit der neuen Installation. Ohne diese Eigenschaft ist kein erfolgreiches Upgrade möglich."
echo "Weitere Informationen hierzu enthält das Thema 'URIs planen' im Information Center."
echo ""
;;

CONTEXT_ROOTS_CANNOT_BE_EQUAL )
echo ""
echo "Das Kontextstammverzeichnis für den JTS ist auf '$2' gesetzt."
echo "Das Kontextstammverzeichnis für die Anwendung ist auf '$3' gesetzt."
echo "Das Kontextstammverzeichnis für den JTS darf nicht dasselbe wie das für die Anwendung sein."
echo ""
;;

esac

}
