#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2012. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************

# ################################################################################
#
# File for messages displayed by the upgrade automated scripts.
#
# ################################################################################


# *********************
# * Messages function *
# *********************
messages() {

case $1 in

# *********************************
# * Initial verification messages *
# *********************************

INVALID_LAUNCH )
echo ""
echo "N'exécutez pas le script app_upgrade directement. Pour mettre à niveau une application, exécutez la commande suivante :"
echo "    relm_upgrade"
echo "Utilisez -help pour afficher la description complète de la commande ci-dessus."
;;

INVALID_START_DIR )
echo ""
echo "Le script $2 ne peut pas être exécuté depuis un répertoire autre que $3, sauf lorsque vous utilisez le paramètre -help."
echo ""
;;


SHOW_PARAM_FILE_NAME )
echo ""
echo "Le fichier '$2' contient les valeurs des paramètres du script de mise à niveau."
echo "Pour modifier ces valeurs de paramètre par défaut, éditez ces fichiers ou spécifiez les valeurs de paramètre sous forme d'arguments de ligne de commande pour les scripts de mise à niveau."
echo ""
;;

SHOW_PARAM_FILE_NAMES_LIST )
echo ""
echo "Le fichier suivant contient les valeurs des paramètres par défaut d'une mise à niveau d'application. Si vous devez modifier ces valeurs, vous pouvez modifier le fichier ou définir les valeurs des paramètres comme arguments de ligne de commande dans le script de mise à niveau."
echo "- Mise à niveau RELM :  $2/params/relm_params$3.sh"
echo ""
;;


# ************************************
# * Parameters verification messages *
# ************************************

# Intrinsic verification
# ======================

MISSING_APP_TYPE )
echo ""
echo "Aucun type d'application défini. Pour mettre à niveau l'application, exécutez  la commande suivante :"
echo "    relm_upgrade"
echo "Utilisez -help pour afficher la description complète de la commande ci-dessus."
echo ""
;;

INVALID_APP_TYPE )
echo ""
echo "$2 n'est pas un type d'application valide. Pour mettre à niveau l'application, exécutez la commande suivante :"
echo "    relm_upgrade"
echo "Utilisez -help pour afficher la description complète de la commande ci-dessus."
echo ""
;;

MISSING_PARAM_VALUE )
echo ""
echo "Valeur manquante pour le paramètre $2."
echo "Utilisez -help pour afficher la description complète des paramètres."
echo ""
;;

INVALID_PARAM_DIR )
echo ""
echo "Le répertoire $3, défini pour le paramètre $2, n'existe pas ou n'est pas valide."
echo "Utilisez -help pour afficher la description complète des paramètres."
echo ""
;;

RELATIVE_PARAM_DIR )
echo ""
echo "Le répertoire $3 défini pour le paramètre $2 doit être un chemin absolu."
echo "Utilisez -help pour afficher la description complète des paramètres."
echo ""
;;

INVALID_PARAM_FILE )
echo ""
echo "Le fichier $3, spécifié pour le paramètre $2, n'existe pas ou n'est pas valide."
echo "Utilisez -help pour afficher la description complète des paramètres."
echo ""
;;

INVALID_PARAM_VALUE )
echo ""
echo "$3 n'est pas une valeur valide pour le paramètre $2."
echo "Utilisez -help pour afficher la description complète des paramètres."
echo ""
;;

INVALID_PARAM )
echo ""
echo "$2 est un paramètre inconnu."
echo "Utilisez -help pour afficher la description complète des paramètres."
echo ""
;;


# Extrinsic verification
# ======================

MISSING_HOME_PARAM )
echo ""
echo "Paramètre de répertoire de base $2 manquant."
echo "Utilisez -help pour afficher la description complète des paramètres."
echo ""
;;

DIR_NOT_FOUND )
echo ""
echo "Le répertoire $2 n'existe pas ou n'est pas valide."
echo ""
;;

CMD_NOT_FOUND_2X_APP )
echo ""
echo "La commande repotools '$2' de l'application est introuvable."
echo ""
echo "Vérifiez que le paramètre -oldApplicationHome '$3' pointe vers l'ancien répertoire de configuration de serveur, par exemple, 'JazzInstallDir/server/conf'."
echo ""
;;

CMD_NOT_FOUND_OLD_APP )
echo ""
echo "La commande repotools '$2' de l'application est introuvable."
echo ""
echo "Vérifiez que le paramètre -oldApplicationHome '$3' pointe vers l'ancien répertoire de configuration de serveur, par exemple, 'JazzInstallDir/server/conf' et que le paramètre jtsContextRoot '$4' est correct."
echo ""
;;

TSP_NOT_FOUND_2X_APP )
echo ""
echo "Le fichier de configuration '$2' est introuvable."
echo ""
echo "Vérifiez que le paramètre -oldApplicationHome '$3' pointe vers l'ancien répertoire de configuration de serveur, par exemple, 'JazzInstallDir/server/conf'."
echo ""
;;

TSP_NOT_FOUND_OLD_APP )
echo ""
echo "Le fichier de configuration '$2' est introuvable."
echo ""
echo "Vérifiez que le paramètre -oldApplicationHome '$3' pointe vers l'ancien répertoire de configuration de serveur, par exemple, 'JazzInstallDir/server/conf' et que le paramètre jtsContextRoot '$4' est correct."
echo ""
;;

CMD_NOT_FOUND_NEW_APP )
echo ""
echo "La commande repotools '$2' de l'application est introuvable."
echo ""
echo "Vérifiez que le paramètre -newApplicationHome '$3' pointe vers le nouveau répertoire de configuration de serveur d'applications, par exemple, 'JazzInstallDir/server/conf' et que le paramètre jtsContextRoot '$4' est correct."
echo "Si vous mettez à niveau une version précédente, vérifiez que vous avez sélectionné les racines de contexte correcets. Par exemple, si vous utilisez le gestionnaire d'installation, vous devez sélectionner l'option de racine de contexte $5 dans le panneau "Context Root Options" .  Si vous avez sélectionné une option différente par erreur, vous devez réinstaller le produit avec l'option de racine de contexte $5."
echo ""
;;

TSP_NOT_FOUND_NEW_APP )
echo ""
echo "Le fichier de configuration '$2' est introuvable."
echo ""
echo "Vérifiez que le paramètre -newApplicationHome '$3' pointe vers le nouveau répertoire de configuration de serveur JTS, par exemple, 'JazzInstallDir/server/conf' et que le paramètre jtsContextRoot '$4' est correct."
echo "Si vous mettez à niveau une version précédente, vérifiez que vous avez sélectionné les racines de contexte correctes. Par exemple, si vous utilisez le gestionnaire d'installation, vous devez sélectionner l'option de racine de contexte $5 dans le panneau "Context Root Options" .  Si vous avez sélectionné une option différente par erreur, vous devez réinstaller le produit avec l'option de racine de contexte $5."
echo ""
;;

CMD_NOT_FOUND_OLD_JTS )
echo ""
echo "Impossible de trouver la commande repotools JTS '$2'."
echo ""
echo "Vérifiez que le paramètre -oldJTSHome '$3' pointe vers l'ancien répertoire de configuration de serveur JTS, par exemple, 'JazzInstallDir/server/conf' et que le paramètre jtsContextRoot '$4' est correct."
echo ""
;;

TSP_NOT_FOUND_OLD_JTS )
echo ""
echo "Le fichier de configuration '$2' est introuvable."
echo ""
echo "Vérifiez que le paramètre -oldJTSHome '$3' pointe vers l'ancien répertoire de configuration de serveur JTS, par exemple, 'JazzInstallDir/server/conf' et que le paramètre jtsContextRoot '$4' est correct."
echo ""
;;

CMD_NOT_FOUND_NEW_JTS )
echo ""
echo "Impossible de trouver la commande repotools JTS '$2'."
echo ""
echo "Vérifiez que le paramètre -newJTSHome '$3' pointe vers le nouveau répertoire de configuration de serveur JTS, par exemple, 'JazzInstallDir/server/conf' et que le paramètre jtsContextRoot '$4' est correct."
echo ""
;;

TSP_NOT_FOUND_NEW_JTS )
echo ""
echo "Le fichier de configuration '$2' est introuvable."
echo ""
echo "Vérifiez que le paramètre -newJTSHome '$3' pointe vers le nouveau répertoire de configuration de serveur JTS, par exemple, 'JazzInstallDir/server/conf' et que le paramètre jtsContextRoot '$4' est correct."
echo ""
;;

MISSING_IMPORT_FROM_FILE )
echo ""
echo "Un fichier tar contenant des données 2.x est requis pour la mise à niveau de $2."
echo "Utilisez -help pour afficher la description complète des paramètres."
echo ""
;;


# **********************
# * Execution messages *
# **********************

BANNER_relm )
echo ""
echo ""
echo "============================================"
echo "===    Mise à niveau RELM    ==="
echo "============================================"
echo ""
;;


# *********************
# * First step switch *
# *********************

INITIAL_STEP_FAILED )
echo ""
echo "La dernière exécution a échoué lors de l'étape initiale..."
;;

LAST_STEP_FAILED )
echo ""
echo "La dernière exécution a échoué lors de l'étape $2..."
echo "Voulez-vous redémarrer la mise à niveau depuis cette étape ou une étape précédente ?"
;;

ALREADY_RUN )
echo ""
echo "La mise à niveau a déjà été effectuée et a abouti..."
echo "Voulez-vous redémarrer une nouvelle mise à niveau à partir d'une étape spécifique ?"
;;

LAST_STEP_PASSED )
echo ""
echo "La dernière exécution a été arrêtée avec succès à l'étape $2..."
echo "Voulez-vous redémarrer la mise à niveau à partir de l'étape en cours $3 ou d'une étape précédente ?"
;;

ENTER_NEXT_STEP )
echo ""
echo "Entrez le numéro de l'étape [$2-$3] à partir de laquelle vous voulez effectuer la mise à niveau ou appuyez sur [Entrée] pour annuler :"
;;

INTEGER_STEP_NUMBER )
echo ""
echo "'$2' n'est pas un nombre. Entrez un numéro d'étape valide."
;;

INVALID_STEP_NUMBER )
echo ""
echo "'$2' n'est pas un numéro d'étape valide. Entrez un numéro d'étape valide."
;;

MAX_STEP_NUMBER )
echo ""
echo "$2 est la dernière étape. Par conséquent, vous ne pouvez pas redémarrer la mise à niveau à partir de l'étape $3."
;;

NUM_MAX_STEP_NUMBER )
echo ""
echo "L'étape $2 n'a pas encore été exécutée. Par conséquent, vous ne pouvez pas redémarrer la mise à niveau à partir de l'étape $3."
;;


# **********************
# * Messages for Steps *
# **********************

STEP_0_IBMi )
echo "Etape 0 : suppression des tables"
echo "-------------------"
;;

STEP_0 )
echo "Etape 0 : mise à jour des fichiers de configuration"
echo "---------------------------"
;;

STEP_1_ADD )
echo "Etape 1 : ajout des tables"
echo "------------------"
;;

FULL_TEXT_INDICES_STEP )
echo "Etape $2 : régénération des index de texte"
echo "----------------------------"
;;

JFS_INDICES_STEP )
echo "Etape $2 : recréation des index de requête et de recherche"
echo "-----------------------------------------"
;;

STEP_2_UPGRADE_DATA_WAREHOUSE )
echo "Etape 2 : mise à niveau du schéma d'entrepôt"
echo "-------------------------------------"
;;

OVERALL_MIGRATION_FAILED )
echo ""
echo "La mise à niveau $2 a échoué à l'étape $3. Résolvez le problème et exécutez de nouveau le script à partir de l'étape $3."
echo ""
;;

OVERALL_MIGRATION_SUCCESS_RELM )
echo ""
echo "La mise à niveau $2 a échoué. Si vous avez déjà mis à niveau JTS et des applications dépendantes (telles que VVC, LQE et Sparql_Gateway), vous pouvez démarrer maintenant les serveurs dans le déploiement."
echo ""
;;

# *******************************
# * Messages while running step *
# *******************************

STEP_DIR_CMD )
echo ""
echo "Répertoire : $2"
echo "Commande :"
;;

ENTER_STEP_ACTION )
echo "Entrez [E] pour exécuter cette étape, [S] pour l'ignorer ou appuyez sur [Entrée] pour annuler l'exécution du script :"
;;

INVALID_STEP_ACTION )
echo ""
echo "'$2' est une entrée non valide. Seul 'E', 'S' ou 'Entrée' est autorisé."
echo ""
;;

EDIT_TEAMSERVER_PROPERTIES )
echo ""
echo "Un éditeur vi va s'ouvrir pour que vous puissiez vérifier le fichier $2 teamserver.properties."
echo "Vérifiez que la racine d'URI public indiquée par la propriété com.ibm.team.repository.server.webapp.url est correcte."
echo "Vérifiez que les propriétés de la base de données sont correctes."
echo "Lorsque vous avez terminé, sauvegardez les modifications éventuelles, puis fermez l'éditeur afin de continuer l'exécution du script."
echo ""
;;

PAUSE )
echo ""
echo "Entrez [C] pour continuer l'exécution ou appuyez sur [Entrée] pour annuler l'exécution du script :"
;;

INVALID_PAUSE_ACTION )
echo ""
echo ".'$2' n'est pas une entrée valide ; seul 'C' ou 'Entrée' est autorisé."
echo ""
;;

COPY_INDICES_FAILED )
echo ""
echo "Echec de la copie des index de texte de '$2' vers '$3'."
echo "Vérifiez la propriété com.ibm.team.fulltext.indexLocation"
echo "définie dans le fichier teamserver.properties."
echo "Copiez manuellement les index de texte vers ce répertoire"
echo "ou exécutez repotools -rebuildTextIndices pour les régénérer."
echo ""
;;

# *****************************************
# * Messages for Public URIs verification *
# *****************************************

MISSING_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ERROR !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "Aucun URI public défini"
echo "dans $3,"
echo "; la mise à niveau ne peut pas être démarrée."
echo ""
echo "Ce fichier ne contient pas d'URI public défini comme suit :"
echo "https\://hostname.example.com\:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "L'URI public property com.ibm.team.repository.server.webapp.url doit se trouver dans le fichier teamserver.properties."
echo "Ajoutez la propriété au fichier teamserver.properties de l'ancienne installation et affectez-lui l'URI racine que tous les clients utilisent pour accéder au serveur."
echo "L'URI public est indispensable au bon fonctionnement de votre nouvelle installation. Sans cette propriété, la mise à niveau ne pourra pas aboutir.  "
echo "Pour plus d'informations, voir la rubrique InfoCentern, 'Planification de vos URI'."
echo ""
;;

COMMENTED_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ERREUR !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "Tous les URI publics définis dans"
echo "$3,"
echo "sont mis en commentaire et la mise à niveau ne peut donc pas être démarrée."
echo ""
echo "Ce fichier doit comporter un URI public non commenté défini comme suit :"
echo "https/://hostname.example.com/:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "La propriété d'URI public com.ibm.team.repository.server.webapp.url doit figurer dans le fichier teamserver.properties."
echo "Ajoutez la propriété au fichier teamserver.properties de l'ancienne installation et affectez-lui l'URI racine que tous les clients utilisent pour accéder au serveur."
echo "L'URI public est indispensable au bon fonctionnement de votre nouvelle installation. Sans cette propriété, la mise à niveau ne pourra pas aboutir."
echo "Pour plus d'informations, voir la rubrique 'Planification de vos URI dans le centre de documentation."
echo ""
;;

CONTEXT_ROOTS_CANNOT_BE_EQUAL )
echo ""
echo "'$2' est défini comme racine de contexte pour JTS."
echo "'$3' est défini comme racine de contexte pour l'application."
echo "Les racines de contexte de JTS et de l'application ne peuvent pas être identiques."
echo ""
;;

esac

}
