#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2012. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************

# ################################################################################
#
# File for messages displayed by the upgrade automated scripts.
#
# ################################################################################


# *********************
# * Messages function *
# *********************
messages() {

case $1 in

# *********************************
# * Initial verification messages *
# *********************************

INVALID_LAUNCH )
echo ""
echo "Não execute o script app_upgrade diretamente. Para atualizar um aplicativo, execute o seguinte comando:"
echo "    relm_upgrade"
echo "Use -help para obter uma descrição completa do comando acima."
;;

INVALID_START_DIR )
echo ""
echo "Exceto ao usar o parâmetro -help, o script $2 não pode ser executado de um diretório diferente de $3"
echo ""
;;


SHOW_PARAM_FILE_NAME )
echo ""
echo "O arquivo '$2' contém os valores de parâmetro para o script de upgrade."
echo "Se for necessário modificar qualquer um dos valores de parâmetro padrão, você poderá editar esses arquivos ou especificar os valores de parâmetro como argumentos da linha de comandos para os scripts de upgrade."
echo ""
;;

SHOW_PARAM_FILE_NAMES_LIST )
echo ""
echo "O arquivo a seguir contém valores de parâmetro padrão para um upgrade do aplicativo. Se for necessário modificar qualquer um dos valores de parâmetro padrão, você poderá editar o arquivo ou especificar os valores de parâmetro como argumentos da linha de comandos para o script de upgrade."
echo "- RELM upgrade:  $2/params/relm_params$3.sh"
echo ""
;;


# ************************************
# * Parameters verification messages *
# ************************************

# Intrinsic verification
# ======================

MISSING_APP_TYPE )
echo ""
echo "Nenhum tipo de aplicativo foi especificado. Para atualizar o aplicativo, execute o seguinte comando:"
echo "    relm_upgrade"
echo "Use -help para obter uma descrição completa do comando acima."
echo ""
;;

INVALID_APP_TYPE )
echo ""
echo "$2 não é um tipo de aplicativo válido. Para atualizar o aplicativo, execute o seguinte comando:"
echo "    relm_upgrade"
echo "Use -help para obter uma descrição completa do comando acima."
echo ""
;;

MISSING_PARAM_VALUE )
echo ""
echo "Valor ausente para o parâmetro $2."
echo "Use -help para obter uma descrição completa de parâmetros."
echo ""
;;

INVALID_PARAM_DIR )
echo ""
echo "O diretório $3, especificado para o parâmetro $2, não existe ou não é válido."
echo "Use -help para obter uma descrição completa de parâmetros."
echo ""
;;

RELATIVE_PARAM_DIR )
echo ""
echo "O diretório $3 especificado para o parâmetro $2 deve ser um caminho absoluto."
echo "Use -help para obter uma descrição completa de parâmetros."
echo ""
;;

INVALID_PARAM_FILE )
echo ""
echo "O arquivo $3, especificado para o parâmetro $2, não existe ou não é válido."
echo "Use -help para obter uma descrição completa de parâmetros."
echo ""
;;

INVALID_PARAM_VALUE )
echo ""
echo "$3 é um valor inválido para o parâmetro $2."
echo "Use -help para obter uma descrição completa de parâmetros."
echo ""
;;

INVALID_PARAM )
echo ""
echo "$2 é um parâmetro desconhecido."
echo "Use -help para obter uma descrição completa de parâmetros."
echo ""
;;


# Extrinsic verification
# ======================

MISSING_HOME_PARAM )
echo ""
echo "Parâmetro de diretório inicial $2 ausente."
echo "Use -help para obter uma descrição completa de parâmetros."
echo ""
;;

DIR_NOT_FOUND )
echo ""
echo "O diretório $2 não existe ou não é válido."
echo ""
;;

CMD_NOT_FOUND_2X_APP )
echo ""
echo "Não é possível localizar o comando repotools '$2' do aplicativo."
echo ""
echo "Verifique se o parâmetro -oldApplicationHome '$3' está apontando para o antigo diretório de configuração do servidor, por exemplo, 'JazzInstallDir/server/conf'."
echo ""
;;

CMD_NOT_FOUND_OLD_APP )
echo ""
echo "Não é possível localizar o comando repotools '$2' do aplicativo."
echo ""
echo "Verifique se o parâmetro -oldApplicationHome '$3' está apontando para o antigo diretório de configuração do servidor, por exemplo, 'JazzInstallDir/server/conf' e se o parâmetro jtsContextRoot '$4' está correto."
echo ""
;;

TSP_NOT_FOUND_2X_APP )
echo ""
echo "Não é possível localizar o arquivo de configuração '$2'."
echo ""
echo "Verifique se o parâmetro -oldApplicationHome '$3' está apontando para o antigo diretório de configuração do servidor, por exemplo, 'JazzInstallDir/server/conf'."
echo ""
;;

TSP_NOT_FOUND_OLD_APP )
echo ""
echo "Não é possível localizar o arquivo de configuração '$2'."
echo ""
echo "Verifique se o parâmetro -oldApplicationHome '$3' está apontando para o antigo diretório de configuração do servidor, por exemplo, 'JazzInstallDir/server/conf' e se o parâmetro jtsContextRoot '$4' está correto."
echo ""
;;

CMD_NOT_FOUND_NEW_APP )
echo ""
echo "Não é possível localizar o comando repotools '$2' do aplicativo."
echo ""
echo "Verifique se o parâmetro -newApplicationHome '$3' está apontando para o novo diretório de configuração do servidor de aplicativos, por exemplo, 'JazzInstallDir/server/conf' e se o parâmetro jtsContextRoot '$4' está correto."
echo "Se estiver atualizando de uma liberação anterior, assegure-se de ter selecionado as raízes de contexto corretas. Por exemplo, se estiver usando o Installation Manager, você deverá selecionar a opção da raiz de contexto $5 no painel "Context Root Options" . Se tiver selecionado acidentalmente uma opção diferente, você deverá reinstalar o produto com a opção da raiz de contexto $5."
echo ""
;;

TSP_NOT_FOUND_NEW_APP )
echo ""
echo "Não é possível localizar o arquivo de configuração '$2'."
echo ""
echo "Verifique se o parâmetro -newApplicationHome '$3' está apontando para o novo diretório de configuração do servidor JTS, por exemplo, 'JazzInstallDir/server/conf' e se o parâmetro jtsContextRoot '$4' está correto."
echo "Se estiver atualizando de uma liberação anterior, assegure-se de ter selecionado as raízes de contexto corretas. Por exemplo, se estiver usando o Installation Manager, você deverá selecionar a opção da raiz de contexto $5 no painel "Context Root Options" . Se tiver selecionado acidentalmente uma opção diferente, você deverá reinstalar o produto com a opção da raiz de contexto $5."
echo ""
;;

CMD_NOT_FOUND_OLD_JTS )
echo ""
echo "Não é possível localizar o comando repotools '$2' do JTS."
echo ""
echo "Verifique se o parâmetro -oldJTSHome '$3' está apontando para o antigo diretório de configuração do servidor JTS, por exemplo, 'JazzInstallDir/server/conf' e se o parâmetro jtsContextRoot '$4' está correto."
echo ""
;;

TSP_NOT_FOUND_OLD_JTS )
echo ""
echo "Não é possível localizar o arquivo de configuração '$2'."
echo ""
echo "Verifique se o parâmetro -oldJTSHome '$3' está apontando para o antigo diretório de configuração do servidor JTS, por exemplo, 'JazzInstallDir/server/conf' e se o parâmetro jtsContextRoot '$4' está correto."
echo ""
;;

CMD_NOT_FOUND_NEW_JTS )
echo ""
echo "Não é possível localizar o comando repotools '$2' do JTS."
echo ""
echo "Verifique se o parâmetro -newJTSHome '$3' está apontando para o novo diretório de configuração do servidor JTS, por exemplo, 'JazzInstallDir/server/conf' e se o parâmetro jtsContextRoot '$4' está correto."
echo ""
;;

TSP_NOT_FOUND_NEW_JTS )
echo ""
echo "Não é possível localizar o arquivo de configuração '$2'."
echo ""
echo "Verifique se o parâmetro -newJTSHome '$3' está apontando para o novo diretório de configuração do servidor JTS, por exemplo, 'JazzInstallDir/server/conf' e se o parâmetro jtsContextRoot '$4' está correto."
echo ""
;;

MISSING_IMPORT_FROM_FILE )
echo ""
echo "Um arquivo tar contendo dados 2.x é requerido para o upgrade $2."
echo "Use -help para obter uma descrição completa de parâmetros."
echo ""
;;


# **********************
# * Execution messages *
# **********************

BANNER_relm )
echo ""
echo ""
echo "============================================"
echo "===    RELM Upgrade    ==="
echo "============================================"
echo ""
;;


# *********************
# * First step switch *
# *********************

INITIAL_STEP_FAILED )
echo ""
echo "A última execução falhou na etapa inicial..."
;;

LAST_STEP_FAILED )
echo ""
echo "A última execução falhou na etapa $2..."
echo "Deseja reiniciar o upgrade desta etapa ou de uma anterior?"
;;

ALREADY_RUN )
echo ""
echo "O upgrade já estava pronto e concluído com êxito..."
echo "Deseja reiniciar um novo de uma etapa específica?"
;;

LAST_STEP_PASSED )
echo ""
echo "A última execução foi interrompida com êxito na etapa $2..."
echo "Deseja reiniciar o upgrade da etapa atual $3 ou de uma anterior?"
;;

ENTER_NEXT_STEP )
echo ""
echo "Insira o número da etapa [$2-$3] da qual deseja reiniciar o upgrade ou pressione [Enter] para Cancelar:"
;;

INTEGER_STEP_NUMBER )
echo ""
echo "'$2' não é um número. Insira um número de etapa válido."
;;

INVALID_STEP_NUMBER )
echo ""
echo "'$2' é um número de etapa inválido. Insira um número de etapa válido."
;;

MAX_STEP_NUMBER )
echo ""
echo "A última etapa é a $2, portanto, você não pode reiniciar o upgrade na etapa $3."
;;

NUM_MAX_STEP_NUMBER )
echo ""
echo "A etapa $2 ainda não foi executada, portanto, você não pode reiniciar o upgrade na etapa $3."
;;


# **********************
# * Messages for Steps *
# **********************

STEP_0_IBMi )
echo "Etapa 0: Eliminar tabelas"
echo "-------------------"
;;

STEP_0 )
echo "Etapa 0: Atualizar arquivos de configuração"
echo "---------------------------"
;;

STEP_1_ADD )
echo "Etapa 1: Incluir tabelas"
echo "------------------"
;;

FULL_TEXT_INDICES_STEP )
echo "Etapa $2: Reconstruir índices do texto"
echo "----------------------------"
;;

JFS_INDICES_STEP )
echo "Etapa $2: Recriar consulta e índices de procura"
echo "-----------------------------------------"
;;

STEP_2_UPGRADE_DATA_WAREHOUSE )
echo "Etapa 2: Atualizar o esquema de armazém de dados"
echo "-------------------------------------"
;;

OVERALL_MIGRATION_FAILED )
echo ""
echo "O upgrade $2 falhou na etapa $3. Corrija o problema e execute o script novamente iniciando na etapa $3."
echo ""
;;

OVERALL_MIGRATION_SUCCESS_RELM )
echo ""
echo "o upgrade $2 foi bem-sucedido. Se você também atualizou o JTS e os aplicativos dependentes (como VVC, LQE e Sparql_Gateway), poderá, agora, iniciar os servidores em sua implementação."
echo ""
;;

# *******************************
# * Messages while running step *
# *******************************

STEP_DIR_CMD )
echo ""
echo "Diretório: $2"
echo "Comando:"
;;

ENTER_STEP_ACTION )
echo "Pressione [E] para executar esta etapa, [S] para ignorá-la ou pressione [Enter] para cancelar a execução do script:"
;;

INVALID_STEP_ACTION )
echo ""
echo "'$2' é uma entrada inválida, apenas 'E', 'S' ou 'Enter' é permitido"
echo ""
;;

EDIT_TEAMSERVER_PROPERTIES )
echo ""
echo "Um editor vi será aberto para permitir a verificação do arquivo teamserver.properties $2."
echo "Verifique se a raiz da URI Pública simbolizada pela propriedade com.ibm.team.repository.server.webapp.url está correta."
echo "Verifique se as propriedades do banco de dados estão corretas."
echo "Quando estiver pronto, salve as mudanças, se houver alguma, e feche o editor para continuar a execução do script."
echo ""
;;

PAUSE )
echo ""
echo "Pressione [C] para continuar a execução ou pressione [Enter] para cancelar a execução do script:"
;;

INVALID_PAUSE_ACTION )
echo ""
echo "'$2' é uma entrada inválida, apenas 'C' ou 'Enter' é permitido"
echo ""
;;

COPY_INDICES_FAILED )
echo ""
echo "Falha ao copiar índices do texto de '$2' para '$3'."
echo "Verifique a propriedade com.ibm.team.fulltext.indexLocation"
echo "definida no arquivo teamserver.properties."
echo "Copie manualmente os índices do texto para este diretório"
echo "ou execute repotools -rebuildTextIndices para reconstruí-los."
echo ""
;;

# *****************************************
# * Messages for Public URIs verification *
# *****************************************

MISSING_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ERRO !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "Não há nenhuma URI Pública definida em"
echo "$3,"
echo "portanto, o upgrade não pode ser iniciado."
echo ""
echo "Deve haver uma URI Pública neste arquivo definido da seguinte forma:"
echo "https\://hostname.example.com\:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "A propriedade com.ibm.team.repository.server.webapp.url da URI Pública deve estar presente no arquivo teamserver.properties."
echo "Inclua a propriedade no arquivo teamserver.properties da antiga instalação e configure o valor para ser a raiz da URI que todos os clientes usam para atingir o servidor."
echo "A raiz da URI Pública é essencial para o funcionamento adequado da nova instalação. O upgrade não será bem-sucedido sem essa propriedade.  "
echo "Para obter mais informações, consulte o tópico InfoCenter em 'Planejando suas URIs'."
echo ""
;;

COMMENTED_PUBLIC_URI )
echo ""
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!! ERRO !!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "Todas as URIs Públicas definidas em"
echo "$3,"
echo "são comentadas, portanto, o upgrade não pode ser iniciado."
echo ""
echo "Ele deve ter uma URI Pública não comentada neste arquivo definida da seguinte forma:"
echo "https/://hostname.example.com/:port/$2"
echo ""
echo "!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!!"
echo ""
echo "A propriedade com.ibm.team.repository.server.webapp.url da URI Pública deve estar presente no arquivo teamserver.properties."
echo "Inclua a propriedade no arquivo teamserver.properties da antiga instalação e configure o valor para ser a raiz da URI que todos os clientes usam para atingir o servidor."
echo "A raiz da URI Pública é essencial para o funcionamento adequado da nova instalação. O upgrade não será bem-sucedido sem essa propriedade."
echo "Para obter mais informações, consulte o tópico InfoCenter em 'Planejando suas URIs'."
echo ""
;;

CONTEXT_ROOTS_CANNOT_BE_EQUAL )
echo ""
echo "A raiz de contexto para o JTS é configurada como '$2'."
echo "A raiz de contexto para o aplicativo é configurada como '$3'."
echo "A raiz de contexto para o jts e o aplicativo não pode ser a mesma."
echo ""
;;

esac

}
