#!/bin/sh
# *******************************************************************************
#  Licensed Materials - Property of IBM
#  (c) Copyright IBM Corporation 2012. All Rights Reserved.
#
#  Note to U.S. Government Users Restricted Rights:
#  Use, duplication or disclosure restricted by GSA ADP Schedule
#  Contract with IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Umgebungsvariablen gem den Parametern und Standard-
# # werten im Script 'relm_upgrade.bat' definieren
# #
# #===========================================================
# #
# # Diese Datei wird zu Beginn der Ausfhrung des Scripts
# # 'relm_upgrade.bat' gelesen. Pro gltigem Parameter wird eine
# # Umgebungsvariable mit vordefiniertem Standardwert gesetzt.
# #
# # Benutzer knnen den Standardwert ndern und das
# # Script 'relm_upgrade.bat' mit eigenen Werten starten. Die
# # Parameter und ihre Werte mssen dabei nicht manuell in
# # der Befehlszeile eingegeben werden.
# #
# # WARNUNG:
# # Nicht alle Variablen mssen fr jede Anwendung gesetzt
# # werden. Modifizieren Sie einen Wert erst, nachdem Sie
# # sorgfltig den zugehrigen Kommentar gelesen haben.
# #
# #############################################################

# Parameter: -oldApplicationHome
# Usage: -oldApplicationHome <Verzeichnispfad>
# Beschreibung:
# 	Vollstndiger Pfad zum Ausgangsverzeichnis fr Anwendungen in der alten Installation.
# Standardwert:
# 	<ohne>
# Einschrnkungen:
#  - Dies ist ein obligatorischer Parameter.
#  - <Verzeichnispfad> muss ein vorhandenes Verzeichnis sein, das auf 'server\conf' endet,
#    e.g. /opt/ibm/JazzInstallDir/server/conf
#
OLD_APPLICATION_HOME=

# Parameter: -applicationContextRoot
# Syntax: -applicationContextRoot <Stammverzeichnis>
# Beschreibung:
# 	Kontextstammverzeichnis fr Anwendungen.
# Standardwert:
# 	relm
# Einschrnkungen:
#  - <Stammverzeichnis> muss ein gltiger Verzeichnisname ohne vorangestellten Schrgstrich sein.
#
APPLICATION_CONTEXT_ROOT=relm

# Parameter: -oldApplicationVersion
# Usage: -oldApplicationVersion <version>
# Beschreibung:
# 	Die RELM-Version, fr die das Upgrade durchgefhrt wird. Standardmig wird sie
#     mit 'repotools -version' fr die alte Anwendung ermittelt.
# Standardwert:
# 	<ohne>
# Einschrnkungen:
#  - Es sollte sich um eine vollstndige Versionszeichenfolge handeln,
#    z. B. 1.0.0.1.
#
OLD_APPLICATION_VERSION=

# Parameter: -newApplicationHome
# Syntax: -newApplicationHome <Verzeichnispfad>
# Beschreibung:
# 	Pfad zum Ausgangsverzeichnis fr Anwendungen in der neuen Installation.
# Standardwert:
# 	<aktuelles Verzeichnis>/conf
# Einschrnkungen:
#  - Dies ist ein obligatorischer Parameter.
#  - <Verzeichnispfad> muss ein vorhandenes Verzeichnis sein, das auf 'server\conf' endet,
#     e.g. /opt/ibm/JazzInstallDir/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# Parameter: -updateTomcatFiles
# Usage: -updateTomcatFiles <yes | no>
# Beschreibung:
# 	Angabe, ob die Tomcat-Konfigurationsdateien aktualisiert
#  werden sollen.
# Standardwert:
# 	yes
# Einschrnkungen:
#  - Gltig sind nur die Werte 'yes' und 'no'.
#
UPDATE_TOMCAT_FILES=yes

# Parameter: -oldApplicationTomcatHome
# Syntax: -oldApplicationTomcatHome <Verzeichnispfad>
# Beschreibung:
# 	Vollstndiger Pfad zum Tomcat-Stammverzeichnis in der alten Installation.
# Standardwert:
# 	<ohne>
# Einschrnkungen:
#  - Das Verzeichnis muss vorhanden sein.
#
OLD_APP_TOMCAT_HOME=

# Parameter: -newApplicationTomcatHome
# Syntax: -newApplicationTomcatHome <Verzeichnispfad>
# Beschreibung:
# 	Pfad zum Tomcat-Stammverzeichnis fr Anwendungen in der neuen Installation.
# Standardwert:
# 	<ohne>
#
NEW_APP_TOMCAT_HOME=

# Parameter: -newJTSHome
# Syntax: -newJTSHome <Verzeichnispfad>
# Beschreibung:
# 	Pfad zum JTS-Serverkonfigurationsverzeichnis, das von der neuen Installation verwendet wird.
# Standardwert:
#  Ausgangsverzeichnis der neuen Anwendung
# Einschrnkungen:
#  - <Verzeichnispfad> muss ein vorhandenes Verzeichnis sein, das mit 'server\conf' endet.
#
NEW_JTS_HOME=

# Parameter: -jtsContextRoot
# Usage: -jtsContextRoot <root>
# Beschreibung:
# 	Kontextstammverzeichnis des JTS-Servers.
# Standardwert:
# 	jts
# Einschrnkungen:
#  - <Stammverzeichnis> muss ein gltiger Verzeichnisname
#    ohne vorangestellten Schrgstrich sein.
#
JTS_CONTEXT_ROOT=jts

# Parameter: -noPrompt
# Usage: -noPrompt
# Beschreibung:
# 	Beim Erstellen oder Modifizieren der Tabellen keine Besttigung anfordern
# Standardwert:
# 	<ohne>
# Einschrnkungen:
#  - Die einzigen gltigen Werte sind eine leere Zeichenfolge und 'noPrompt'.
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Parameter: -noVerify
# Usage: -noVerify
# Beschreibung:
# 	Keine Verifizierung fr Team-Server-Eigenschaftendateien durchfhren
# Standardwert:
# 	<ohne>
# Einschrnkungen:
#  - Gltig sind nur eine leere Zeichenfolge und 'noVerify'.
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Parameter: -overwrite
# Usage: -overwrite
# Beschreibung:
# 	Angabe, ob vorhandene Dateien berschrieben werden sollen
# Standardwert:
# 	no
# Einschrnkungen:
#  - Gltig sind nur eine leere Zeichenfolge und 'overwrite=yes'.
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Parameter: -noStepPrompt
# Usage: -noStepPrompt
# Beschreibung:
# 	Keine Besttigung fr die Ausfhrung eines Schrittes anfordern
# Standardwert:
# 	false
# Einschrnkungen:
#  - Gltig sind nur die Werte 'true' und 'false'.
#
# NO_STEP_PROMPT=true
set NO_STEP_PROMPT=false
