#!/bin/sh
# *******************************************************************************
#  Materiale su licenza - Propriet di IBM
#  (c) Copyright IBM Corporation 2006, 2012. Tutti i diritti riservati.
#
#  Nota relativa a limitazioni dei diritti per gli utenti del Governo degli Stati Uniti:
#  L'uso, la duplicazione o la divulgazione sono limitati dal GSA ADP Schedule
#  Contract con IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# # Definizione delle variabili d'ambiente corrispondenti ai
# # parametri dello script relm_upgrade.sh e ai relativi
# # valori predefiniti.
# #
# #===========================================================
# #
# # Questo file viene letto all'inizio dell'esecuzione dello
# # script relm_upgrade.sh. Esso imposta una variabile di
# # ambiente per parametro valido con un valore predefinito.
# #
# # Gli utenti potrebbero voler modificare il valore predefinito
# # per avviare lo script relm_upgrade.sh con i propri valori
# # senza dover immettere il parametro e il corrispondente
# # valore manualmente sulla riga comandi.
# #
# # AVVERTENZA:
# # Non tutte le variabili devono essere impostate in base
# # all'applicazione aggiornata.  Leggere attentamente ogni commento
# # prima di modificare il valore.
# #
# #############################################################

# Parametro: -oldApplicationHome
# Uso: -oldApplicationHome <dir path>
# Descrizione:
# 	Il percorso completo della directory home dell'applicazione
#  nell'installazione precedente.
# Valore predefinito:
# 	<nessuno>
# Limitazioni:
#  - questo  un parametro obbligatorio
#  - <percorso dir> deve essere una directory esistente che termina con 'server\conf'
#    ad esempio D:\Jazz\IBM\JazzInstallDir\jazz\server\conf
#
OLD_APPLICATION_HOME=

# Parametro: -applicationContextRoot
# Uso: -applicationContextRoot <root>
# Descrizione:
# 	La root di contesto dell'applicazione.
# Valore predefinito:
# 	relm
# Limitazioni:
#  - <root> deve essere un singolo nome directory valido (senza barra iniziale)
#
APPLICATION_CONTEXT_ROOT=relm

# Parametro: -oldApplicationVersion
# Uso: -oldApplicationVersion <versione>
# Descrizione:
# 	La versione RELM che viene aggiornata. Per impostazione predefinita, questa 
# determinata eseguendo repotools -version rispetto alla vecchia applicazione.
# Valore predefinito:
# 	<nessuno>
# Limitazioni:
#  - deve essere una stringa di versione completa
#    ad esempio 1.0.0.1
#
OLD_APPLICATION_VERSION=

# Parametro: -newApplicationHome
# Uso: -newApplicationHome <percorso dir>
# Descrizione:
# 	Il percorso della directory home dell'applicazione nella nuova installazione.
# Valore predefinito:
# 	<dirCorrente>/conf
# Limitazioni:
#  - questo  un parametro obbligatorio
#  - <percorso dir> deve essere una directory esistente che termina con 'server\conf'
#    ad esempio D:\Jazz\IBM\JazzInstallDir\server\conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# Parametro: -updateTomcatFiles
# Uso: -updateTomcatFiles <s | no>
# Descrizione:
# 	Indica se aggiornare i file di configurazione tomcat.
# Valore predefinito:
# 	yes
# Limitazioni:
#  - Gli unici valori validi sono 'yes' e 'no'
#
UPDATE_TOMCAT_FILES=yes

# Parametro: -oldApplicationTomcatHome
# Uso: -oldApplicationTomcatHome <percorso dir>
# Descrizione:
# 	Il percorso completo della directory root Tomcat nell'installazione precedente.
# Valore predefinito:
# 	<nessuno>
# Limitazioni:
#  - Deve essere una directory esistente
#
OLD_APP_TOMCAT_HOME=

# Parametro: -newApplicationTomcatHome
# Uso: -newApplicationTomcatHome <percorso dir>
# Descrizione:
# 	Il percorso della directory root Tomcat dell'applicazione nella nuova installazione.
# Valore predefinito:
# 	<nessuno>
#
NEW_APP_TOMCAT_HOME=

# Parametro: -newJTSHome
# Uso: -newJTSHome <dir path>
# Descrizione:
# 	Il percorso della directory di configurazione del server JTS utilizzato dalla nuova installazione.
# Valore predefinito:
# La nuova directory home dell'applicazione
# Limitazioni:
#  - <percorso dir> deve essere una directory esistente che termina con 'server\conf'
#
NEW_JTS_HOME=

# Parametro: -jtsContextRoot
# Uso: -jtsContextRoot <root>
# Descrizione:
# 	La root di contesto del server JTS.
# Valore predefinito:
# 	jts
# Limitazioni:
#  - <root> deve essere una singola directory valida (senza barra iniziale)
#
JTS_CONTEXT_ROOT=jts

# Parametro: -noPrompt
# Uso: -noPrompt
# Descrizione:
# Non richiede prima di creare o modificare le tabelle
# Valore predefinito:
# 	<nessun valore>
# Limitazioni:
#  - Gli unici valori validi sono il valore vuoto o 'noPrompt'
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Parametro: -noVerify
# Uso: -noVerify
# Descrizione:
# Non esegue la verifica dei file teamserver.properties.
# Valore predefinito:
# 	<nessun valore>
# Limitazioni:
#  - Gli unici valori validi sono il valore vuoto o 'noVerify'
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Parametro: -overwrite
# Uso: -overwrite
# Descrizione:
# Indica se sovrascrivere un file esistente.
# Valore predefinito:
# 	no
# Limitazioni:
#  - Gli unici valori validi sono il valore vuoto o 'overwrite=yes'
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Parametro: -noStepPrompt
# Uso: -noStepPrompt
# Descrizione:
# Non richiede prima di eseguire un passo.
# Valore predefinito:
# 	false
# Limitazioni:
#  - Gli unici valori validi sono 'true' e 'false'
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false
