#!/bin/sh
# *******************************************************************************
#  Materiais Licenciados - Propriedade da IBM
#  (c) Copyright IBM Corporation 2006, 2012. Todos os Direitos Reservados.
#
#  Nota sobre Direitos Restritos para Usurios do Governo dos Estados Unidos:
#  Uso, duplicao ou divulgao restritos pelo documento GSA ADP Schedule
#  Contract com a IBM Corp.
#  *******************************************************************************
# NLS_MESSAGEFORMAT_NONE
# NLS_ENCODING=UTF-8


# #############################################################
# #
# # Defina as variveis de ambiente correspondentes aos
# # parmetros de relm_upgrade.sh e seus valores padro
# #
# #===========================================================
# #
# # Este arquivo  lido no incio da execuo do script
# # relm_upgrade.sh. Ele configura uma varivel de ambiente
# # por parmetro vlido com um valor padro predefinido.
# #
# # Os usurios podem desejar modificar o valor padro para
# # ativar o script relm_upgrade.sh com seus prprios valores
# # sem precisar inserir o parmetro e seus
# # valores correspondentes manualmente na linha de comandos
# #
# # WARNING:
# # Nem todas as variveis precisam ser configuradas para todo
# # aplicativo.  Leia cada comentrio cuidadosamente antes de modificar
# # o valor.
# #
# #############################################################

# Parmetro: -oldApplicationHome
# Uso: -oldApplicationHome <dir path>
# Descrio:
# 	Caminho completo para o diretrio inicial do aplicativo na instalao antiga.
# Padro:
# 	<nenhum>
# Restries:
#  - este  um parmetro obrigatrio
#  - <dir path> deve ser um diretrio existente terminando com 'server\conf'
#    e.g. /opt/ibm/JazzInstallDir/server/conf
#
OLD_APPLICATION_HOME=

# Parmetro: -applicationContextRoot
# Uso: -applicationContextRoot <root>
# Descrio:
# 	Raiz de contexto do aplicativo.
# Padro:
# 	relm
# Restries:
#  - <root> deve ser um nome nico de diretrio vlido (isto , nenhuma barra  esquerda)
#
APPLICATION_CONTEXT_ROOT=relm

# Parmetro: -oldApplicationVersion
# Uso: -oldApplicationVersion <version>
# Descrio:
# 	A verso RELM que est sendo atualizada.  Por padro, isso 
#     determinado executando repotools -version no aplicativo antigo.
# Padro:
# 	<nenhum>
# Restries:
#  - deve ser uma sequncia de verses completa
#    e.g. 1.0.0.1
#
OLD_APPLICATION_VERSION=

# Parmetro: -newApplicationHome
# Uso: -newApplicationHome <dir path>
# Descrio:
# 	Caminho para o diretrio inicial do aplicativo na nova instalao.
# Padro:
# 	<currentDir>/conf
# Restries:
#  - Este  um parmetro obrigatrio
#  - <dir path> deve ser um diretrio existente finalizado por 'server\conf'
#     e.g. /opt/ibm/JazzInstallDir/server/conf
#
NEW_APPLICATION_HOME="$START_DIR/conf"

# Parmetro: -updateTomcatFiles
# Uso: -updateTomcatFiles <yes | no>
# Descrio:
# 	Se os arquivos de configurao tomcat devem ser atualizados.
# Padro:
# 	yes
# Restries:
#  - Os nicos valores vlidos so 'yes' e 'no'
#
UPDATE_TOMCAT_FILES=sim

# Parmetro: -oldApplicationTomcatHome
# Uso: -oldApplicationTomcatHome <dir path>
# Descrio:
# 	Caminho completo para o diretrio raiz do Tomcat na instalao antiga.
# Padro:
# 	<nenhum>
# Restries:
#  - Deve ser um diretrio existente
#
OLD_APP_TOMCAT_HOME=

# Parmetro: -newApplicationTomcatHome
# Uso: -newApplicationTomcatHome <dir path>
# Descrio:
# 	Caminho para o diretrio raiz do aplicativo Tomcat na instalao nova.
# Padro:
# 	<nenhum>
#
NEW_APP_TOMCAT_HOME=

# Parmetro: -newJTSHome
# Uso: -newJTSHome <dir path>
# Descrio:
# 	Caminho para o diretrio de configurao do servidor JTS do JTS que a nova instalao utilizar.
# Padro:
# 	O novo diretrio inicial do aplicativo
# Restries:
#  - <dir path> deve ser um diretrio existente finalizando com 'server\conf'
#
NEW_JTS_HOME=

# Parmetro: -jtsContextRoot
# Uso: -jtsContextRoot <root>
# Descrio:
# 	Raiz de contexto do servidor JTS.
# Padro:
# 	jts
# Restries:
#  - <root> deve ser um nome nico de diretrio vlido (isto , nenhuma barra  esquerda)
#
JTS_CONTEXT_ROOT=jts

# Parmetro: -noPrompt
# Uso: -noPrompt
# Descrio:
# 	No avisar antes de criar ou modificar as tabelas
# Padro:
# 	<nenhum>
# Restries:
#  - Os nicos valores vlidos so empty ou 'noPrompt'
#
# NO_PROMPT=noPrompt
NO_PROMPT=

# Parmetro: -noVerify
# Uso: -noVerify
# Descrio:
#  No execute a verificao de arquivos teamserver.properties.
# Padro:
# 	<nenhum>
# Restries:
#  - Os nicos valores vlidos so vazio ou 'noVerify'
#
# NO_VERIFY=noVerify
NO_VERIFY=

# Parmetro: -overwrite
# Uso: -overwrite
# Descrio:
# 	Se deve-se sobrescrever qualquer arquivo existente.
# Padro:
# 	no
# Restries:
#  - Os nicos valores vlidos so vazio ou 'overwrite=yes'
#
# OVERWRITE=overwrite=yes
OVERWRITE=

# Parmetro: -noStepPrompt
# Uso: -noStepPrompt
# Descrio:
# 	No avisar antes de executar uma etapa.
# Padro:
# 	false
# Restries:
#  - Os nicos valores vlidos so 'true' e 'false'
#
# NO_STEP_PROMPT=true
NO_STEP_PROMPT=false
